@@ -42,7 +42,7 @@ class Product:
 
 
   def load(self, store):
-    product_url = f"{store.base_url}/{self.id}"
+    product_url = f"{store.base_url}/product/{self.id}"
 
     raw_page = Product._request_page(product_url)
 
