@@ -10,4 +10,4 @@ class Store:
   def base_url(self):
     protocol = "http" if self.insecure else "https"
 
-    return f"{protocol}://{self.hostname}/{self.lang}/product"
\ No newline at end of file
+    return f"{protocol}://{self.hostname}/{self.lang}"
\ No newline at end of file
